/* ========================================================================= */
/* HELPERS ================================================================= */
/* ========================================================================= */

getDevice = function() {
	return (
		window.getComputedStyle(
	    	document.querySelector('html'), ':before'
		).getPropertyValue('content')
	);
};

trimInput = function(value) {
	return value.replace(/^\s*|\s*$/g, '');
};

/* ========================================================================= */
/* FUNCTIONS =============================================================== */
/* ========================================================================= */

var siteHandler = {
	/**
	 * Carga un template con los datos que recibe como parámetro.
	 *
	 * @param  {String}   name    	- Nombre del fichero .hbs donde se encuentra el template
	 * @param  {String}   where   	- Selector CSS donde vamos a insertar el template
	 * @param  {Object}	  context	- Objeto con los datos que va a utilizar el template
	 * @param  {Boolean}  append  	- Si es true inserta el template al final de un contenedor para no borrar su contenido
	 * @param  {Function} callback  - Función de callback
	 */
	loadTemplate: function(name, where, context, append, func) {
		var location = where || '#' + name,
			data = context,
			template = JST['app/templates/' + name + '.hbs'],
			html = template(data),
			callback = func;

		if (append)
			$(location).append(html);
		else
			document.querySelector(location).innerHTML = html;
		if (func)
			callback();
	},
	/**
	 * Establece los eventos de la app
	 */
	setEvents: {
		// To Do:

		// Añadir evento para esconder/mostrar animals. Primero añadir animated y fade a todos los icons y luego aplicar .closed
		activeCategory: function() {
			$('.category').on('click', function(event) {
				event.preventDefault();
				/* Act on the event */
				var $this    = $(event.currentTarget),
					$animals = $this.next();
				if ($animals.hasClass('closed')){
					$animals.one("webkitTransitionEnd otransitionend oTransitionEnd msTransitionEnd transitionend", function(event) {
						// Do something when the transition ends
						if ($this.hasClass('salvajes')){
							$animals.addClass('no-after');
							$this.removeClass('no-after');
						}
						$animals.find('img').addClass('animated fadeIn').animate({ opacity: 1 }, function(){

						});
					});
					$animals.removeClass('z0 closed');

					//scroll to..
					var target = $(this);
					scroll = $('#mainWrapper').scrollTop();
					$('#mainWrapper').stop().animate({
				  		scrollTop: $(target).offset().top + $(target).outerHeight() +scroll - 15
				  	}, 1000);
				}
				else {
					$animals.find('img').removeClass('animated fadeIn').animate({ opacity: 0 }, function(){
						if ($this.hasClass('salvajes')){
							$animals.removeClass('no-after');
							$this.addClass('no-after');
						}
						$animals.one("webkitTransitionEnd otransitionend oTransitionEnd msTransitionEnd transitionend", function(event) {
							// Do something when the transition ends
							$animals.addClass('z0');
						});
						$animals.addClass('closed');
					});
				}
			});
		},
		activeLegend: function() {
			$('#curtainIcon').on('click', function(event) {
				event.preventDefault();
				$(this).find('i').toggleClass('fa-search-plus fa-search-minus');
				/* Act on the event */
				$('.legend-wrapper').toggleClass('closed');
			});
			$('#infoIcon').on('click', function(event) {
		        event.preventDefault();
		        event.stopPropagation();
		        /* Act on the event */
		        siteHandler.loadTemplate($(this).data('modal'),'#nucleusModal .modal-body');
		        $('#nucleusModal').modal();
		    });
		}
	},
	init: function() {
		//load template layout (header, grid, and site-canvas)
		this.loadTemplate('layout', '#mainWrapper', null, false, function(){
			siteHandler.loadTemplate('main');
			siteHandler.setEvents.activeCategory();
			siteHandler.setEvents.activeLegend();
		});
	}
};

siteHandler.init();
